@@ -46,18 +46,26 @@ class Player(Base):
         if isinstance(time, str):
             time = parse(time)
 
-        players = chronicler.get_player_updates(id_, before=time, order="desc", count=1)
+        players = list(chronicler.get_entities("player", id_=id_, at=time))
         if len(players) == 0:
             return None
         return cls(dict(players[0]["data"], timestamp=time))
 
     @classmethod
-    def load_history(cls, id_, order='desc'):
+    def load_all(cls):
+        """
+        Load all players
+        """
+        players = chronicler.get_entities("player")
+        return {x["entityId"]: cls(x["data"]) for x in players}
+
+    @classmethod
+    def load_history(cls, id_, order='desc', count=None):
         """
         Returns array of Player stat changes with most recent first.
         """
-        players = chronicler.get_player_updates(ids=id_, order=order)
-        return [cls(dict(p['data'], timestamp=p['firstSeen'])) for p in players]
+        players = chronicler.get_versions("player", id_=id_, order=order, count=count)
+        return [cls(dict(p['data'], timestamp=p['validFrom'])) for p in players]
 
     @classmethod
     def load_all_by_gameday(cls, season, day):
@@ -201,11 +209,18 @@ class Player(Base):
 
     @property
     def soulscream(self):
+        return self.get_soulscream()
+
+    def get_soulscream(self, collapse=True):
         letters = ["A", "E", "I", "O", "U", "X", "H", "A", "E", "I"]
         stats = [self.pressurization, self.divinity, self.tragicness, self.shakespearianism, self.ruthlessness]
 
         scream = []
-        for r in range(self.soul):
+        if collapse:
+            soul_max = min(self.soul, 300)
+        else:
+            soul_max = self.soul
+        for r in range(soul_max):
             sub_scream = []
             i = 10 ** -r
             for s in stats:
@@ -216,7 +231,10 @@ class Player(Base):
                     sub_scream.append("undefined")
             scream.extend(sub_scream + sub_scream + [sub_scream[0]])
 
-        return ''.join(scream)
+        scream = ''.join(scream)
+        if collapse and self.soul > 300:
+            scream += f"... (CONT. FOR {self.soul - 300} SOUL)"
+        return scream
 
     @Base.lazy_load("_blood_id", cache_name="_blood", use_default=False)
     def blood(self):
