@@ -10,6 +10,7 @@ from .helpers import TestBase, CASSETTE_DIR
 
 
 class TestPlayer(TestBase):
+    @pytest.mark.vcr
     def test_base_compliance(self, player):
         self.base_test(player)
 
@@ -86,6 +87,12 @@ class TestPlayer(TestBase):
             assert isinstance(player.peanut_allergy, bool)
         if getattr(player, "fate", None) is not None:
             assert isinstance(player.fate, int)
+        if getattr(player, "e_density", None) is not None:
+            assert isinstance(player.e_density, float)
+        if getattr(player, "state", None) is not None:
+            assert isinstance(player.state, dict)
+        if getattr(player, "evolution", None) is not None:
+            assert isinstance(player.evolution, int)
 
     # TODO: Use One fixture for these so we can actually do a bounded check
     def test_simulated_copy_mult(self, player):
@@ -313,6 +320,14 @@ class TestPlayer(TestBase):
         test_player = Player.find_by_name("Chorby Soul")
         test_value = test_player.soulscream
         assert isinstance(test_value, str)
+        assert test_value[-22:] in f"... (CONT. FOR {test_player.soul-300} SOUL)"
+
+    @pytest.mark.vcr
+    def test_long_soulscream_extralong(self):
+        """Test very long soulscreams"""
+        test_player = Player.find_by_name("Chorby Soul")
+        test_value = test_player.get_soulscream(collapse=False)
+        assert isinstance(test_value, str)
         assert test_value[-9:] == "undefined"
 
     # TODO: Set up random override to properly test this
@@ -379,7 +394,7 @@ class TestPlayer(TestBase):
 
     @pytest.mark.vcr
     def test_load_history(self):
-        player = Player.load_history("0bd5a3ec-e14c-45bf-8283-7bc191ae53e4")
+        player = Player.load_history("0bd5a3ec-e14c-45bf-8283-7bc191ae53e4", count=200)
         assert isinstance(player, list)
         assert len(player) > 0
         for player in player:
@@ -387,7 +402,7 @@ class TestPlayer(TestBase):
 
     @pytest.mark.vcr
     def test_load_history_bad_id(self):
-        bad_player = Player.load_history("00000000-0000-0000-0000-000000000000")
+        bad_player = Player.load_history("00000000-0000-0000-0000-000000000000", count=200)
         assert isinstance(bad_player, list)
         assert len(bad_player) == 0
 
@@ -453,6 +468,16 @@ class TestPlayer(TestBase):
         bad_day = Player.load_by_gameday("f70dd57b-55c4-4a62-a5ea-7cc4bf9d8ac1", season=6, day=999)
         assert bad_day is None
 
+    @pytest.mark.vcr
+    def test_load_all(self):
+        all_players = Player.load_all()
+        assert isinstance(all_players, dict)
+        assert len(all_players) > 0
+        for id_, p in all_players.items():
+            assert isinstance(p, Player)
+            assert isinstance(id_, str)
+            assert id_ == p.id
+
     # FIXTURES
 
     @pytest.fixture(scope="module")
